function [string,comp,param]=mucomp(n)
%    [STRING,COMP,PARAM]=MUCOMP(N)
% extract the name and indices of the n-th menu parameter 
% from the present model
% returns 
% STRING = the name (e.g. 'mu phi'), 
% COMP = the component index in the model (e.g. 2 for mu in damu) 
% PARAM = the parameter index in the component list (e.g 3 for phi in mu) 
% invoked by MUEDITPARAMETERS, MUFIT_GUI, MUPLOTPAR, MUPARSE

global MU_MODEL
cn=MU_MODEL.COMPONENTNUMBER; % e.g 2, this model has 2 components
parpercomp=cell2mat({MU_MODEL.COMPONENT.PARAMETERNUMBER}); % e.g. 1 5
% the first component (da) has 1 parameter
% the second component (mu) has 5 parameters
ptot=sum(parpercomp);% e.g. 6 (1+5)
if n>ptot|n<=0|n~=fix(n)
  string=[];
  comp=-1;
  param=0; % not found
else
  cs=cumsum(parpercomp); % e.g. 1 6
  comp=min(find(n<=cs)); % detects wether n is in first or second component
  if comp==1
    param=n; % in this case n is directly the index of the parameter 
             % in the component list
  else
    param=n-cs(comp-1); % now param is the index of the parameter
                        % in the component list
  end
  component=MU_MODEL.COMPONENT(comp).NAME;
  parameter=MU_MODEL.COMPONENT(comp).PARAMETER(param).NAME;
  parameter(1)=upper(parameter(1));
  string=[component parameter];
  %disp(string)
end