%KTDYNA    Dynamical Kuto-Toyabe, DTSCM approx
%Usage:
%  [y, t] = muktdyna(atomic,Npoints,dt,P,nu);
%
%input arguments:
%
%static: atomic function name, mugkt or mulkt
%     N: number of sampling points;

%    dt: time interval per bin [i.e. time base is t = dt*(0:N-1)]
%     P: Gaussian/Lorantzian distribution width (us-1) , external longitudinal field (G) 
%    nu: scattering frequency.
%alphaN: [optional argument] weighting coefficient alpha times N. Default=10 

function [dkt, t] = muktdyna(atomic,N,dt,P,nu);

alphaN=10; %auto-default
Npad=N * 2; % number of total time points, includes as many zeros

tt = dt*(0:Npad-1);
expwei = exp(-(alphaN/(N*dt))*tt);

gg=feval(atomic,P,0,dt,Npad).*(tt < dt*N); %  padded KT, P=R,B R=DEGA or DELO
%    0: first time point
%   dt: ditto
% Npad: ditto
% gg=1/3*(1 + 2*(1 - s^2*tt.^2).*exp(-(.5*s^2)*tt.^2)) % e.g.

ff=fft(gg.*expwei.*exp(-nu*tt));                 %fft(padded_KT*exp(-nu*t))
FF=exp(-nu*dt)*ff./(1-(1-exp(-nu*dt))*ff); %%(1-nu*dt*ff);  

dkt = real(ifft(FF))./expwei;  %ifft
dkt=dkt(1:N); %/dkt(1); 

if (nargout > 1),
  t = tt(1:N);
end

