function f=muoniumtriplet(p,data)
% Muonium Triplet precession in Transverse Field
% generates two damped waves.
% p(1) is Amp 
% p(2) is Hyperfine frequency (MHz)
% p(3) is Gau
% p(4) is Phi
% nuplus= (Gamu+Game)*p(3)
% numinus= (Game-Gamu)*p(3)
% Det= sqrt(p(2)^2+nuplus^2)
% The first wave has amplitude p(1)/2*(1-nuplus/Det)
% and Decay rates p(5), DeLo, p(6) DeGa
% The second p(1)/2*(1+nuplus/Det)
% and Decay rates p(7), DeLo, p(8), DeGa
global MU_TABLE
Nuplus=(MU_TABLE.GAMU+MU_TABLE.GAME)*p(3);
Numinus=(-MU_TABLE.GAMU+MU_TABLE.GAME)*p(3);
Det=sqrt(p(2)^2+Nuplus^2);
nu1=(Numinus-Det+p(2))/2;
nu2=(Numinus+Det-p(2))/2;
a1=p(1)/2*(1-Nuplus/Det);
a2=p(1)/2*(1+Nuplus/Det);
f=a1*cos(2*pi*(nu1*data(1,:)+p(4)/360)).*exp(-data(1,:)*p(5)).* ...
  exp(-(data(1,:)*p(6)).^2/2) + ...
  a2*cos(2*pi*(nu2*data(1,:)+p(4)/360)).*exp(-data(1,:)*p(7)).* ...
  exp(-(data(1,:)*p(8)).^2/2);