function muplotfit(varargin)
% usage MUPLOTFIT or MUPLOTFIT(2)
% 
% plot fit result
%
% usage MUPLOTFIT(1)
% 
% plot fit starting guess
%
% usage MUPLOTFIT(1,RANGE)
% 
% plot fit starting guess over RANGE=[startbin stopbin] 
% e.g. RANGE=[1 200]
%
% usage MUPLOTFIT(2,RANGE)
% 
% plot fit result over RANGE=[startbin stopbin] 
% e.g. RANGE=[1 200]

global MU_DATA
global MU_MODEL
global MU_MODEL_F
global MU_ADD
global MU_FIG


if ~isfield(MU_DATA,'DATA')
    disp('****')
    disp('  You must first load a data set!')
    return
end
white=[1 1 1];
red=[0.9 0.2 0.2];
green=[0.2 0.7 0.3];
blue=[0.1 0.1 0.7];
orange=[0.9 0.5 0.1];
purple=[0.7 0.3 0.5];
colormap(lines)
startguess=1; % default: plot starting guess
firstplot=0;
if isempty(varargin)&isfield(MU_MODEL_F,'CHI') % called from mufit after a 
    % best fit attempt
    startguess=[];
    startbin=MU_MODEL.RANGE(1);
    stopbin=MU_MODEL.RANGE(2);
    % save tqhese settings for rotframe replots
    MU_FIG.FITSTARTSTOP=[startbin stopbin startguess];
elseif length(varargin)==3  % called from RotFrame_CallBack, use stored values
    replot=1;
    if length(MU_FIG.FITSTARTSTOP)==3
       startguess=MU_FIG.FITSTARTSTOP(3);
    end
    startbin=MU_FIG.FITSTARTSTOP(1);
    stopbin=MU_FIG.FITSTARTSTOP(2);
elseif length(varargin)==2  % called from mufit_gui, also range specified
    flag=varargin{1};
    if flag==2, startguess=[]; end % plot best fit result
    range=varargin{2};
    startbin=range (1);
    stopbin=range(2);
    % save these settings for rotframe replots
    MU_FIG.FITSTARTSTOP=[startbin stopbin startguess];
else % only flag, no range
    flag=varargin{1};
    if flag==2, startguess=[]; end % plot best fit result
    startbin=MU_MODEL.RANGE(1); % range is fit range
    stopbin=MU_MODEL.RANGE(2);
    % save these settings for rotframe replots
    MU_FIG.FITSTARTSTOP=[startbin stopbin startguess];    
end
%
% recalculate array SHARE which redistributes parameters
% must have as many elements as the total number of parameters
% but share(j) is the index of par inside fminuit 
% where += parameters do not appear

% must be done in case a fit was not performed yet
% on 1.05 must add LINEAR RELATIONS
shareglobal=[];
par=0;
% FIRST PASSAGE: ~!=, + are just counted in
for k=1:MU_MODEL.COMPONENTNUMBER
    share=[]; % this is the component SHARE array
    for j=1:MU_MODEL.COMPONENT(k).PARAMETERNUMBER
        switch MU_MODEL.COMPONENT(k).PARAMETER(j).FLAG
          case {'~','!'}
            par=par+1; % index is incremented only for ~! parameters
            share=[share par];
            shareglobal=[shareglobal par];
            MU_MODEL.COMPONENT(k).PARAMETER(j).MENU2MINUIT=...
                ['p(' num2str(par) ')']; % new 1.05 version
          case '+'
            share=[share 0];
            shareglobal=[shareglobal 0];
          case '=' % must be a preceding parameter
                parshared=MU_MODEL.COMPONENT(k).PARAMETER(j).SHARE;
                share=[share shareglobal(parshared)];
                shareglobal=[shareglobal shareglobal(parshared)];
                MU_MODEL.COMPONENT(k).PARAMETER(j).MENU2MINUIT=...
                    ['p(' num2str(shareglobal(parshared)) ')']; 
                % new 1.05 version
        end
    end
    %       disp (['comp=' num2str(k) ': ' num2str(share)])
    MU_MODEL.COMPONENT(k).SHARE=share;
end
% SECOND PASSAGE: recalculate +
for k=1:MU_MODEL.COMPONENTNUMBER
    for j=1:MU_MODEL.COMPONENT(k).PARAMETERNUMBER
        switch MU_MODEL.COMPONENT(k).PARAMETER(j).FLAG
          case '+' % linear relation must be reassigned and
                   % stored in 
                   % MU_MODEL.COMPONENT(k).PARAMETER(kp).MENU2MINUIT
            [OK open close par]=muparse(...
                MU_MODEL.COMPONENT(k).PARAMETER(j).LINREL);
            % get open = indices of 'p('
            %     close = indices of ')'
            %     par = indices of SOURCE parameters
            %           in Menu (shareglobal) list
            string=MU_MODEL.COMPONENT(k).PARAMETER(j).LINREL;
            % this is the original relation, already verified
            % by muparse when it was typed in
            % It will be rewritten in string
            for l=1:length(open)
                % first make space
                if close(l)-open(l)==3 % only one digit per index
                    string(open(l)+2:end+1)=['  ' ...
                                        string(close(l):end)];
                    
                    close(l)=close(l)+1; % shift forward
                    for ll=l+1:length(open) % shift forward
                                            % all the following
                        open(ll)=open(ll)+1;
                        close(ll)=close(ll)+1;
                    end
                    % make room for two (blank) digits and
                    % copy rest                          
                else % already two digits per index
                    string(open(l)+2:close(l)-1)='  '; % blank them 
                end 
                % then write reallocated index
                nback=2; % index is one digit
                if fix(shareglobal(par(l))/10) 
                    nback=1; % index is two digits
                      end
                      string(open(l)+2:close(l)-nback)=...
                          num2str(shareglobal(par(l)));
                      % write the fminuit index
                      % between p(_  and _) or __), depending on
                      % number of digits 
            end
            % finaly store in MENU2MINUIT
                  MU_MODEL.COMPONENT(k).PARAMETER(j).MENU2MINUIT=...
                      string; % new 1.05 version
        end
    end
end

muasymmetry;
data=[MU_DATA.TIME(startbin:stopbin); ...
      MU_DATA.ASYMMETRY(startbin:stopbin); ...
      MU_DATA.ASYMERROR(startbin:stopbin)];
if isempty(startguess)
    [mupout dum dumm pf]=mupar; % reads mupout from MU_MODEL_F 
else
    [mupout dum dumm pf]=mupar(startguess); % reads mupout from MU_MODEL 
end
nu=length(data(1,:))-(length(mupout)-pf); % degrees of freedom
chi=mufcn(mupout,data);


dt=data(1,2)-data(1,1);
tmin=min(data(1,:))-2*dt/3;
tmax=max(data(1,:))+2*dt/3;
tfit=tmin:dt/3:tmax;
figure(MU_FIG.FIT);
clf
set(MU_FIG.FIT,'Name',MU_FIG.FITNAME,'Visible','off');
if ~isfield(MU_FIG,'FITROTFREQ')
    MU_FIG.FITROTFREQ=0; % rotating frame frequency (MHz)
    MU_FIG.ROTFILTER=4; % filter in MHz
    MU_FIG.FITROTFRAME=0;
end
hrotframe = uimenu(MU_FIG.FIT,'Label','Rotating Frame');
label=['FreqFMAXuency (MHz) = ' num2str(MU_FIG.FITROTFREQ)];
h1 = uimenu(hrotframe,'Label',label,...
              'Tag','RotFreq',...
              'Callback',@RotFrame_CallBack);
label=['Audio Filter (MHz) = ' num2str(MU_FIG.ROTFILTER)];
h2 = uimenu(hrotframe,'Label',label,...
              'Tag','RotFilter',...
              'Callback',@RotFrame_CallBack);

if MU_FIG.FITROTFRAME
       onoff='ON';
else
       onoff='OFF';
end
h3=uimenu(hrotframe,'Label',onoff,...
              'Tag','ONOFF',...
              'Callback',@RotFrame_CallBack);
h4=uimenu(hrotframe,'Label','Replot',...
              'Tag','Replot',...
              'Callback',@RotFrame_CallBack);


empty=[];
Xmin=0.1;
Ymin=0.1;
Yres=0.2; % was 0.3
Xwidth=0.7;
Ywidth=0.92-Ymin-Yres;

hres=axes('position',[Xmin Ymin Xwidth Yres]);

res=data(2,:)-mufcn(mupout,data(1,:));
%rmin=min(res);
%rmax=max(res);
%dr=rmax-rmin;
%rmin=rmin-0.05*dr;
%rmax=rmax+0.05*dr;
%dr=1.1*dr;
hold(gca,'all')
[x y ey]=murebin(data(1,:),res,data(3,:));
ymin=min(y);
ymax=max(y);
ymin=min([ymin 0]);
ymax=max([ymax 0]);
dy=ymax-ymin;
ymin=ymin-0.05*dy;
ymax=ymax+0.05*dy;
dy=1.1*dy;
%length(x)
%errorbar(x,y,ey,'b.');
lwdt=2;
plot(x,y,'m-')
plot(x,ey,'g-.','color',green,'linewidth',lwdt)
plot(x,-ey,'g-.','color',green,'linewidth',lwdt)
plot(x,2*ey,'y-','color',orange,'linewidth',lwdt)
plot(x,-2*ey,'y-','color',orange,'linewidth',lwdt)
% if length(x)>3000
%     plot(x(1:4:end),y(1:4:end),'m.','color',purple)
%     plot(x,ey,'g-.','color',green,'linewidth',lwdt)
%     plot(x,-ey,'g-.','color',green,'linewidth',lwdt)
%     plot(x,2*ey,'y-','color',orange,'linewidth',lwdt)
%     plot(x,-2*ey,'y-','color',orange,'linewidth',lwdt)   
% elseif length(x)>1000&length(x)<3000
%     plot(x(1:2:end),y(1:2:end),'m.','color',purple)
%     plot(x,ey,'g-.','color',green,'linewidth',lwdt)
%     plot(x,-ey,'g-.','color',green,'linewidth',lwdt)
%     plot(x,2*ey,'y-','color',orange,'linewidth',lwdt)
%     plot(x,-2*ey,'y-','color',orange,'linewidth',lwdt)
% else
%     plot(x,y,'m.','color',purple)
%     plot(x,ey,'g-.','color',green,'linewidth',lwdt)
%     plot(x,-ey,'g-.','color',green,'linewidth',lwdt)
%     plot(x,2*ey,'y-','color',orange,'linewidth',lwdt)
%     plot(x,-2*ey,'y-','color',orange,'linewidth',lwdt)
% end
xlabel('Time (\mus)')
ylabel('Residues')
set(gca,'Box','On')
if x(1)<=0.2
    zero=0;
else
    zero=x(1);
end
axis([zero tmax ymin ymax])
if MU_FIG.FITROTFRAME
    text(tmin+(tmax+tmin)/8,(ymax+7*ymin)/8,...
        'Lab frame',...
        'fontsize',11,'fontname','Arial');

end
hold(gca,'off')
hhist=axes('position',[Xmin+Xwidth+0.01 Ymin 1-Xmin-Xwidth-0.02 Yres]);
hold(gca,'all')
h=hist(y./ey,[-5:5]);
bar([-5:5],h)
xh=[-5:0.2:5];
nuc=nu-length(data(1,:))+length(x); % degrees of freedom for
                                    % rebinned residues
yh=nuc*(normcdf(xh+0.5,0,1)-normcdf(xh-0.5,0,1)); % expected yield for nuc
% gaussian extractions to fall within xh+-0.5 std
% notice that bar histo is with bins=1 std whereas yellow curve
% (yh) is sampled every 0.2*std
plot(xh,yh,'y-','color',orange,'linewidth',2)
set(gca,'yticklabel',empty,'box','on')
axis([-5 5 0 1.05*max([h yh])])
%set(gca,'xticklabel',{[],'-4',[],'-2',[],'0',[],'2',[],'4',[]})
hold(gca,'off')
hplot=axes('position',[Xmin Ymin+Yres Xwidth Ywidth]);
hold(gca,'all')

yfit=mufcn(mupout,tfit);
x=data(1,:);
y=data(2,:);
ey=data(3,:);
FMAX=1000/2/MU_DATA.RESNS;
if MU_FIG.FITROTFRAME
    y=murf(x,y,MU_FIG.FITROTFREQ,MU_FIG.ROTFILTER);
    yfit=murf(tfit,yfit,MU_FIG.FITROTFREQ,MU_FIG.ROTFILTER);
end
[x y ey]=murebin(x,y,ey);
ymin=min(y);
fmin=min(yfit);
ymin=min([ymin fmin]);
ymax=max(y);
fmax=max(yfit);
ymax=max([ymax fmax]);
dy=ymax-ymin;
ymin=ymin-0.05*dy;
ymax=ymax+0.05*dy;
dy=1.1*dy;
lenx=length(x);
%if lenx>500
%    for k=1:lenx;
%    heu=plot([x(k) x(k)],[y(k) y(k)+ey(k)],'r-','color',red);
%    hed=plot([x(k) x(k)],[y(k) y(k)-ey(k)],'r-','color',red);
%    end
%    he=plot(x,y,'ro','markerfacecolor','w',...
%            'markeredgecolor',red,'markersize',4);
    %else

% replace errorbar.m with new errbar.m RDR (simply errorbar with tee set to zero)
    he = errbar(x,y,ey,'color',red);
    hp = plot(x,y,'ro','markerfacecolor','w',...
               'markeredgecolor',red,'markersize',4);
    % flagtype = get(he,'type')
    %end
plot(tfit,yfit,'g-','linewidth',2,'color',green)%,data(1,:),data(2,:),'m-')

ylabel('Asymmetry')
set(gca,'xticklabel',empty,'box','on')
axis([zero tmax ymin ymax])
dtext=0.02*(tmax-tmin);
fsiz=11;
if MU_FIG.FITROTFRAME
    text(tmin+(tmax-tmin)/10,ymin+(ymax-ymin)/6,...
        ['Rotating frame, \nu=' num2str(MU_FIG.FITROTFREQ,3) 'MHz'],...
        'fontsize',fsiz+1,'fontname','Arial','color',red);
end
da=dy;
amax=ymax;
amin=ymin;
ytext=amax+0.06*da;
if isempty(MU_ADD)
    runs=int2str(MU_DATA.NRUN);
else
    arun=num2str(MU_ADD(1));
    for k=2:length(MU_ADD)
        arun=[arun '+' num2str(MU_ADD(k))];
    end
    runs=[int2str(MU_DATA.NRUN) '+' arun];
end
text(tmin-dtext,ytext,[runs '   ' MU_DATA.SAMPLE ...
                   MU_DATA.TEMPERATURE ' ' MU_DATA.FIELD ...
                    ' ' MU_DATA.ORIENTATION,],...
    'fontsize',fsiz,'fontweight','demi','color',blue)

ytext=amin+1.02*da;
fsiz=20;
text(tmax+3*dtext,ytext+0.02*da,'\mu lab','fontsize',fsiz,'fontweight','demi','fontname','Arial','color',blue);
ytext=amin+0.55*da;
text(tmax+dtext,ytext,['F:[' musgroup(1,0) ']'],'fontsize',8);
ytext=amin+0.45*da;
text(tmax+dtext,ytext,['B:[' musgroup(2,0) ']'],'fontsize',8);
ytext=amin+0.35*da;
%string=valerror(ZN_TEMPER(1),ZN_TEMDEV(1));
%text(tmax+dtext,ytext,['T=' string],'fontsize',8);
if isempty(startguess) % it's a fit
    ytext=amin+0.71*da;
    text(tmax+dtext,ytext,['\alpha=' num2str(MU_MODEL_F.ALPHA) ...
                        ',  binned ' num2str(MU_MODEL.BIN) ],'fontsize',8);
    ytext=amin+0.63*da;
    text(tmax+dtext,ytext,[num2str(MU_DATA.RESNS) 'ns/bin'],'fontsize',8);
    ytext=amin+0.92*da;
    text(tmax+dtext,ytext,[MU_MODEL.NAME ' fit'],'fontsize',8); 
    ytext=amin+0.86*da;
    text(tmax+dtext,ytext,['at ' MU_MODEL_F.TIME],'fontsize',8);
    ytext=amin+0.8*da;
    text(tmax+dtext,ytext,['on ' MU_MODEL_F.DATE],'fontsize',8);
else
    ytext=amin+0.71*da;
    text(tmax+dtext,ytext,['\alpha=' num2str(MU_MODEL.ALPHA)...
                        ',  binned ' num2str(MU_MODEL.BIN) ],'fontsize',8);
    ytext=amin+0.63*da;
    text(tmax+dtext,ytext,[num2str(MU_DATA.RESNS) 'ns/bin'],'fontsize',8);
    ytext=amin+0.92*da;
    text(tmax+dtext,ytext,[MU_MODEL.NAME ' guess'],'fontsize',8);
    ytext=amin+0.84*da;
    text(tmax+dtext,ytext,['Run '  MU_DATA.START_TIME ... 
                        ' ' MU_DATA.START_DATE],'fontsize',8);
end    
ytext=amin+0.2*da;

    %     a way to get 2 sigma for chi2
    m=round(nu/4);
    k=[-m:m];
    cc=gammainc((k+nu)/2,nu/2); % muchi2cdf(x,nu) = gammainc(x/2, nu/2);
    lc=1+k(min(find(cc<0.95&cc>0.05)))/nu;
    hc=1+k(max(find(cc<0.95&cc>0.05)))/nu;

text(tmax+dtext,ytext,['\chi^2_r=' num2str(chi/nu,3) '(' num2str(lc,2) ...
     ',' num2str(hc,3) ')' ]);
ytext=amin+0.05*da;
text(tmax+dtext,ytext,['\chi^2_{cdf}=' num2str(gammainc(chi/2,nu/ ...
                                                  2))]);
% muchi2cdf(x,nu) = gammainc(x/2, nu/2);
hold(gca,'off')
set(MU_FIG.FIT,'Visible','on')
function RotFrame_CallBack(varargin)
global MU_FIG MU_DATA

hstrike=varargin{1};
h=guihandles;
tagmenu={'RotFreq' 'RotFilter' 'ONOFF' 'Replot'};

handles=[];

   for tag=tagmenu
       string=cell2mat(tag);
       handles=[handles getfield(h,string)];
   end

switch hstrike
  case handles(1) % RotFreq
      notok=1;
      TITLE='Rotating frame';
      title=TITLE;
      FMAX=1000/2/MU_DATA.RESNS;
      while notok          
          answer=inputdlg('Frequency (MHz)',title,...
            1,{num2str(MU_FIG.FITROTFREQ)});
          freq=str2num(char(answer));
          if freq>=0 && freq <= FMAX;
              MU_FIG.FITROTFREQ=freq;
              notok=0;
          else
              title=['0<=f<=' num2str(FMAX,3) 'MHz!' ];
              disp(['**** WARNING ' title])
          end     
      end
      label=['Frequency (MHz) = ' num2str(MU_FIG.FITROTFREQ)];
      set(handles(1),'Label',label);
  case handles(2) % RotFilter
      notok=1;
      TITLE='Rotating frame';
      title=TITLE;
      FMAX=1000/2/MU_DATA.RESNS;
      while notok          
          answer=inputdlg('Audio Filter (MHz)',title,...
            1,{num2str(MU_FIG.ROTFILTER)});
          freq=str2num(char(answer));
          if freq>=0 && freq <= FMAX;
              MU_FIG.ROTFILTER=freq;
              notok=0;
          else
              title=['0<=f<=' num2str(FMAX,3) 'MHz!' ];
              disp(['**** WARNING ' title])
          end     
      end
      label=['Audio Filter (MHz) = ' num2str(MU_FIG.ROTFILTER)];
      set(handles(2),'Label',label);
  case handles(3) % ONOFF
    OnOff=get(handles,'Label');
    if MU_FIG.FITROTFRAME % toggle on-off
       MU_FIG.FITROTFRAME=0;
       label='OFF';
    else
       MU_FIG.FITROTFRAME=1;
       label='ON';
    end
    set(handles(3),'Label',label);
  case handles(4) % Replot in rotframe
    muplotfit(1,2,3); % regenerate figure with new phase 
    % three arguments is the convention for replotting
end
